@@ -15,10 +15,14 @@ namespace KOSMIndoorMap {
 // - https://taginfo.openstreetmap.org/keys/?key=amenity#values
 // - https://taginfo.openstreetmap.org/keys/?key=shop#values
 // - https://taginfo.openstreetmap.org/keys/?key=tourism#values
+// - https://taginfo.openstreetmap.org/keys/?key=leisure#values
 // - parts of https://taginfo.openstreetmap.org/keys/?key=office#values
 // - parts of https://taginfo.openstreetmap.org/keys/?key=room#values
 static constexpr const ValueMapEntry amenity_map[] = {
     { "alcohol", kli18nc("OSM::amenity/shop", "Alcohol") },
+    { "apartment", kli18nc("OSM::amenity/shop", "Apartment") },
+    { "arts_centre", kli18nc("OSM::amenity/shop", "Arts Center") },
+    { "artwork", kli18nc("OSM::amenity/shop", "Artwork") },
     { "atm", kli18nc("OSM::amenity/shop", "ATM") },
     { "attraction", kli18nc("OSM::amenity/shop", "Attraction") },
     { "bag", kli18nc("OSM::amenity/shop", "Bag") },
@@ -27,6 +31,7 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "bar", kli18nc("OSM::amenity/shop", "Bar") },
     { "beauty", kli18nc("OSM::amenity/shop", "Beauty") },
     { "bed", kli18nc("OSM::amenity/shop", "Bed") },
+    { "bench", kli18nc("OSM::amenity", "Bench") },
     { "beverages", kli18nc("OSM::amenity/shop", "Beverages") },
     { "bicycle", kli18nc("OSM::amenity/shop", "Bicycle") },
     { "bicycle_parking", kli18nc("OSM::amenity/shop", "Bicycle Parking") },
@@ -43,6 +48,7 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "chemist", kli18nc("OSM::amenity/shop", "Chemist") },
     { "chocolate", kli18nc("OSM::amenity/shop", "Chocolate") },
     { "cinema", kli18nc("OSM::amenity/shop", "Cinema") },
+    { "citywalls", kli18nc("OSM::historic", "Citywall") },
     { "clothes", kli18nc("OSM::amenity/shop", "Clothes") },
     { "coffee", kli18nc("OSM::amenity/shop", "Coffee") },
     { "computer", kli18nc("OSM::amenity/shop", "Computer") },
@@ -66,8 +72,10 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "fountain", kli18nc("OSM::amenity/shop", "Fountain") },
     { "furniture", kli18nc("OSM::amenity/shop", "Furniture") },
     { "gallery", kli18nc("OSM::amenity/shop", "Gallery") },
+    { "garden", kli18nc("OSM::amenity/shop", "Garden") },
     { "garden_centre", kli18nc("OSM::amenity/shop", "Garden Center") },
     { "gift", kli18nc("OSM::amenity/shop", "Gift Shop") },
+    { "government", kli18nc("OSM::office", "Government") },
     { "greengrocer", kli18nc("OSM::amenity/shop", "Greengrocer") },
     { "guest_house", kli18nc("OSM::amenity/shop", "Guest House") },
     { "hairdresser", kli18nc("OSM::amenity/shop", "Hairdresser") },
@@ -90,9 +98,12 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "lost_property", kli18nc("OSM::amenity/shop", "Lost & Found") },
     { "luggage_locker", kli18nc("OSM::amenity/shop", "Locker") },
     { "mall", kli18nc("OSM::amenity/shop", "Mall") },
+    { "marketplace", kli18nc("OSM::amenity", "Marketplace") },
     { "medical_supply", kli18nc("OSM::amenity/shop", "Medical Supply") },
+    { "memorial", kli18nc("OSM::historic", "Memorial") },
     { "mobile_phone", kli18nc("OSM::amenity/shop", "Mobile Phone") },
     { "money_transfer", kli18nc("OSM::amenity/shop", "Money Transfer") },
+    { "monument", kli18nc("OSM::historic", "Monument") },
     { "motorcycle_parking", kli18nc("OSM::amenity/shop", "Motorcycle Parking") },
     { "motorcycle_rental", kli18nc("OSM::amenity/shop", "Motorcycle Rental") },
     { "museum", kli18nc("OSM::amenity/shop", "Museum") },
@@ -103,6 +114,7 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "optician", kli18nc("OSM::amenity/shop", "Optician") },
     { "outdoor", kli18nc("OSM::amenity/shop", "Outdoor") },
     { "paint", kli18nc("OSM::amenity/shop", "Paint") },
+    { "park", kli18nc("outdoor recreational area", "Park") },
     { "parking", kli18nc("OSM::amenity/shop", "Parking") },
     { "parking_tickets", kli18nc("OSM::amenity/shop", "Parking Tickets") },
     { "pastry", kli18nc("OSM::amenity/shop", "Pastry") },
@@ -111,6 +123,7 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "pharmacy", kli18nc("OSM::amenity/shop", "Pharmacy") },
     { "photo", kli18nc("OSM::amenity/shop", "Photo") },
     { "place_of_worship", kli18nc("OSM::amenity/shop", "Place of Worship") },
+    { "playground", kli18n("Playground") },
     { "police", kli18nc("OSM::amenity/shop", "Police") },
     { "post_box", kli18nc("OSM::amenity/shop", "Post Box") },
     { "post_office", kli18nc("OSM::amenity/shop", "Post Office") },
@@ -146,6 +159,7 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "waiting", kli18nc("OSM::amenity/shop", "Waiting Area") },
     { "waiting_area", kli18nc("OSM::amenity/shop", "Waiting Area") },
     { "waiting_room", kli18nc("OSM::amenity/shop", "Waiting Area") },
+    { "waste_basket", kli18nc("OSM::amenity", "Waste Basket") },
     { "wine", kli18nc("OSM::amenity/shop", "Wine") },
 };
 static_assert(isSortedLookupTable(amenity_map), "amenity map is not sorted!");
